@@ -8,19 +8,19 @@ Compartment::Compartment(std::string compName, double initVal) {
     this->competingRisks = true;
 }
 
-void Compartment::addOutDistribution(std::shared_ptr<Distribution>& dist, bool distInit) {
-    this->outDistributions.push_back(dist);
+void Compartment::addOutTransition(std::shared_ptr<Transition>& dist, bool distInit) {
+    this->outTransitions.push_back(dist);
     this->distSubCompInit.push_back(distInit);
 }
 
-void Compartment::editOutDistribution(std::string outName, std::shared_ptr<Distribution> &dist, bool distInit) {
+void Compartment::editOutTransition(std::string outName, std::shared_ptr<Transition> &dist, bool distInit) {
     size_t pos = findOutCompPosition(outName);
-    outDistributions[pos] = dist;
+    outTransitions[pos] = dist;
     this->distSubCompInit[pos] = distInit;
 }
 
 void Compartment::setOutValues() {
-    outTotals.resize(outDistributions.size(), 0);
+    outTotals.resize(outTransitions.size(), 0);
 }
 
 // TODO: set length for nested subCompartment
@@ -34,8 +34,8 @@ void Compartment::setLengthSubCompartment() {
         //  --- use same subcompartment chain for competing risks ---- 
         // also uses tmpSubComp to save subComps from last iteration
         this -> subCompartments.resize((size_t) 1);
-        for (size_t pos = 0; pos < outDistributions.size(); pos++){
-            size_t currLength = outDistributions[pos]->getMaxDay();
+        for (size_t pos = 0; pos < outTransitions.size(); pos++){
+            size_t currLength = outTransitions[pos]->getMaxDay();
 
             // update maxLength, which is used as length for outSubcompartment
             if (currLength > maxLength) {
@@ -49,9 +49,9 @@ void Compartment::setLengthSubCompartment() {
     }else{
         //  --- Initialize subCompartment chains for multinomial case ---
         // set first dim for subCompartments
-        this -> subCompartments.resize(outDistributions.size());
-        for (size_t pos = 0; pos < outDistributions.size(); pos++){
-            size_t currLength = outDistributions[pos]->getMaxDay();
+        this -> subCompartments.resize(outTransitions.size());
+        for (size_t pos = 0; pos < outTransitions.size(); pos++){
+            size_t currLength = outTransitions[pos]->getMaxDay();
 
             // update maxLength, which is used as length for outSubcompartment
             if (currLength > maxLength) {
@@ -62,12 +62,12 @@ void Compartment::setLengthSubCompartment() {
             this -> subCompartments[pos].resize(currLength, 0);
 
             if (!distSubCompInit[pos]){
-                // if user specify to not distribute initial value, simply initalize in firs subcompartment
+                // if the user specify to not distribute initial value, simply initalize in firs subcompartment
                 this -> subCompartments[pos][0] = compTotal[0]*outWeights[pos];
             }else{
-                // distribute based on specified outDistribution
+                // distribute based on specified outTransition
                 for(size_t i {0}; i<currLength; ++i){
-                    this-> subCompartments[pos][i] = compTotal[0]*outWeights[pos]*outDistributions[pos]->getProbDist(i);
+                    this-> subCompartments[pos][i] = compTotal[0]*outWeights[pos]*outTransitions[pos]->getProbDist(i);
                 }
             }
             
@@ -128,8 +128,8 @@ std::vector<std::string> Compartment::getOutCompartmentNames() {
     return names;
 }
 
-std::vector<std::shared_ptr<Distribution>> Compartment::getOutDistributions() {
-    return outDistributions;
+std::vector<std::shared_ptr<Transition>> Compartment::getOutTransitions() {
+    return outTransitions;
 }
 
 std::vector<double> Compartment::getOutWeights() {
@@ -183,8 +183,9 @@ void Compartment::updateCompartment(size_t iter, std::vector<std::string>& param
 
     // assign values of current subCompartment to tmpSubComp
     // since tmpSubComp is only used for competingRisk scenario where there is only 1 subCompartment chain, simply get the 1st chain
-    tmpSubComp.assign(subCompartments[0].begin(), subCompartments[0].end());
-
+    if(this->competingRisks){
+        tmpSubComp.assign(subCompartments[0].begin(), subCompartments[0].end());
+    }
 
     // Compute total in value of this compartment (later distributed to first subcompartment of each subcompartments chain)
     double inValue {0};
@@ -204,25 +205,26 @@ void Compartment::updateCompartment(size_t iter, std::vector<std::string>& param
         // update out values and compTotal
         for (size_t outIndex {0}; outIndex < outCompartments.size(); ++outIndex) {
             
-            if (outDistributions[outIndex]->getDistName() == "gamma" ||
-                outDistributions[outIndex]->getDistName() == "weibull" ||
-                outDistributions[outIndex]->getDistName() == "exponential" ||
-                outDistributions[outIndex]->getDistName() == "lognormal" ||
-                outDistributions[outIndex]->getDistName() == "transitionProb" ||
-                outDistributions[outIndex]->getDistName() == "nonparametric") {
+            if (outTransitions[outIndex]->getDistName() == "gamma" ||
+                outTransitions[outIndex]->getDistName() == "weibull" ||
+                outTransitions[outIndex]->getDistName() == "exponential" ||
+                outTransitions[outIndex]->getDistName() == "lognormal" ||
+                outTransitions[outIndex]->getDistName() == "transitionProb" ||
+                outTransitions[outIndex]->getDistName() == "nonparametric") {
                 updateSubCompByDist(iter, outIndex);
-            } else if (outDistributions[outIndex]->getDistName() == "constant") {
+            } else if (outTransitions[outIndex]->getDistName() == "constant") {
                 updateSubCompByConst(iter, outIndex);
             } else {
                 updateSubCompByMath(iter, outIndex, paramNames, paramValues, comps);
             }
  
             // only update chains of subCompartments in multinomial case
-            if(!this->competingRisks){
-
-                // shift subCompartments for next iteration
-                subCompartments[outIndex].pop_back();
-                subCompartments[outIndex].push_front(outWeights[outIndex]*inValue);
+            if(!this->competingRisks){                
+                if(subCompartments[outIndex].size() > (size_t) 1){
+                    // shift subCompartments for next iteration
+                    subCompartments[outIndex].pop_back();
+                    subCompartments[outIndex].push_front(outWeights[outIndex]*inValue);
+                }
             }
         }
     }
@@ -244,24 +246,32 @@ void Compartment::updateCompartment(size_t iter, std::vector<std::string>& param
 /// @param iter current iteration
 /// @param outIndex index of out compartment
 void Compartment::updateSubCompByDist(size_t iter, size_t outIndex) {
-    // Going backward from subCompartments[n] -> subCompartments[1]
-    // This startIndex is to reduce the number of calculations
+    // This endIndex is to reduce the number of calculations
 
-    size_t startIndex {0};
+    size_t endIndex {0};
 
     if(this->competingRisks){
-        startIndex = std::min(iter, subCompartments[0].size() - 1);
-        for (size_t i {0}; i <= startIndex; ++i) { 
-            // if competing risks, update using tmpSubComp instead
-            outTotals[outIndex] += tmpSubComp[startIndex - i]  * outDistributions[outIndex]->getTransitionProb(startIndex - i);
-            subCompartments[0][startIndex - i] -= tmpSubComp[startIndex - i] * outDistributions[outIndex]->getTransitionProb(startIndex - i);
-        }
-
+        endIndex = std::min(iter, subCompartments[0].size() - 1);
+        std::vector<double>& transProbRef = outTransitions[outIndex]->getTransitionProbRef();
+        
+        for (size_t i = 0; i <= endIndex; ++i) { 
+            // if competing risks, compute out population using tmpSubComp instead
+            double out = tmpSubComp[i] * (i >= transProbRef.size() ? 0 : transProbRef[i]);
+            // TODO: check formulation with 1 - exp(-rate) instead 
+            // double out = tmpSubComp[i] * (i >= transProbRef.size() ? 0 : transProbRef[i]);
+            outTotals[outIndex] += out;
+            subCompartments[0][i] -= out;
+        }   
     }else{
-        startIndex = std::min(iter, subCompartments[outIndex].size() - 1);
-        for (size_t i {0}; i <= startIndex; ++i) { 
-            outTotals[outIndex] += subCompartments[outIndex][startIndex - i] * outDistributions[outIndex]->getTransitionProb(startIndex - i);
-            subCompartments[outIndex][startIndex - i] *= (1 - outDistributions[outIndex] -> getTransitionProb(startIndex - i));
+        endIndex = std::min(iter, subCompartments[outIndex].size() - 1);
+        std::vector<double>& transProbRef = outTransitions[outIndex]->getTransitionProbRef();
+        
+        for (size_t i = 0; i <= endIndex; ++i) { 
+            double out = subCompartments[outIndex][i] * (i >= transProbRef.size() ? 0 : transProbRef[i]);
+            // TODO: check formulation with 1 - exp(-rate) instead 
+            // double out = subCompartments[outIndex][i] * (1 - exp(-(i >= transProbRef.size() ? 0 : transProbRef[i])));
+            outTotals[outIndex] += out;
+            subCompartments[outIndex][i] -= out;
         }
     }
 
@@ -270,7 +280,7 @@ void Compartment::updateSubCompByDist(size_t iter, size_t outIndex) {
 }
 
 
-/// @brief Update sub compartment with math expression as distribution
+/// @brief Update sub compartment with math expression as transition
 /// @param iter current iteration
 /// @param outIndex index of out compartment
 /// @param paramNames model parameteres
@@ -279,7 +289,7 @@ void Compartment::updateSubCompByDist(size_t iter, size_t outIndex) {
 void Compartment::updateSubCompByMath(size_t iter, size_t outIndex, std::vector<std::string>& paramNames, std::vector<double>& paramValues,
                 std::vector<std::shared_ptr<Compartment>> &comps) {
     mu::Parser parser;
-    parser.SetExpr(outDistributions[outIndex]->getDistName());
+    parser.SetExpr(outTransitions[outIndex]->getDistName());
     // Add parameter values
     double timeStep = 0;
     for (size_t i {0}; i < paramNames.size(); ++i) {
@@ -302,22 +312,18 @@ void Compartment::updateSubCompByMath(size_t iter, size_t outIndex, std::vector<
 
     // try evaluation
     try {
-        double computeValue = parser.Eval();
+        // automatically multiply by timeStep internally
+        double computeValue = parser.Eval() * timeStep;
     } catch (mu::Parser::exception_type &e) {
-        // std::cerr << "Failed to evaluate expression: " 
-        //         << outDistributions[outIndex]->getDistName() << "\n"
-        //         << "Error message: " << e.GetMsg() << "\n";
-        // throw std::runtime_error("muParser evaluation failed: " + std::string(e.GetMsg()));
-        
+
         std::string msg = 
-          "Failed to evaluate expression: " + outDistributions[outIndex]->getDistName() + "\n" +
+          "Failed to evaluate expression: " + outTransitions[outIndex]->getDistName() + "\n" +
           "Error message: " + std::string(e.GetMsg());
         Rcpp::stop(msg);
     }
 
     // The result of this math expression is the outTotals of this outIndex
-    // double computeValue = outWeights[outIndex] * parser.Eval(); //deprecated code
-    double computeValue = parser.Eval();
+    double computeValue = parser.Eval() * timeStep;
 
     double sumOutTotal = std::accumulate(this -> outTotals.begin(), this -> outTotals.end(), (double) 0);
     
@@ -329,14 +335,16 @@ void Compartment::updateSubCompByMath(size_t iter, size_t outIndex, std::vector<
         outTotals[outIndex] = compTotal[iter - 1] - sumOutTotal;
     }
 
+    // for reducing number of iterations 
+    size_t endIndex {0};
     // Calculate how many people remain in each subCompartment
     if(this->competingRisks){
         double sumSubComp = std::accumulate(this -> subCompartments[0].begin(), this -> subCompartments[0].end(), (double) 0);
         if (sumSubComp > 0) {
             double remainPct = (sumSubComp - outTotals[outIndex]) / sumSubComp;
+            endIndex = std::min(iter, subCompartments[0].size() - 1);
 
-            // TODO: alternate algorithm for improve runtime
-            for (size_t i_subComp {0}; i_subComp < subCompartments[0].size(); ++i_subComp) { 
+            for (size_t i_subComp {0}; i_subComp < endIndex; ++i_subComp) { 
                 // if competing risks, update using tmpSubComp instead
                 subCompartments[0][i_subComp] -= tmpSubComp[i_subComp] * (1-remainPct);
             }
@@ -345,7 +353,8 @@ void Compartment::updateSubCompByMath(size_t iter, size_t outIndex, std::vector<
         double sumSubComp = std::accumulate(this -> subCompartments[outIndex].begin(), this -> subCompartments[outIndex].end(), (double) 0);
         if (sumSubComp > 0) {
             double remainPct = (sumSubComp - outTotals[outIndex]) / sumSubComp;
-            for (size_t i_subComp {0}; i_subComp < subCompartments[outIndex].size(); ++i_subComp) {
+            endIndex = std::min(iter, subCompartments[outIndex].size() - 1);
+            for (size_t i_subComp {0}; i_subComp < endIndex; ++i_subComp) {
                 subCompartments[outIndex][i_subComp] *= remainPct;
             }
         }
@@ -359,7 +368,7 @@ void Compartment::updateSubCompByMath(size_t iter, size_t outIndex, std::vector<
 /// @param outIndex index of out compartment
 void Compartment::updateSubCompByConst(size_t iter, size_t outIndex) {
 
-    double computeValue = outDistributions[outIndex]->getTransitionProb(iter);
+    double computeValue = outTransitions[outIndex]->getTransitionProb(iter);
     double sumOutTotal = std::accumulate(this -> outTotals.begin(), this -> outTotals.end(), (double) 0);
     // To prevent a compartment being negative, only use this value if it + sum of
     // previous out total <= the compTotal of previous iteration
