@@ -12,14 +12,14 @@
 #include "Compartment.h"
 #include "Model.h"
 #include "myProb.h"
-#include "DistributionNonparametric.h"
-#include "DistributionMathExpression.h"
-#include "DistributionConstant.h"
-#include "DistributionTransitionProb.h"
-#include "DistributionDiscreteGamma.h"
-#include "DistributionDiscreteWeibull.h"
-#include "DistributionDiscreteExponential.h"
-#include "DistributionLogNormal.h"
+#include "TransitionNonparametricDist.h"
+#include "TransitionMathExpression.h"
+#include "TransitionConstant.h"
+#include "TransitionProb.h"
+#include "TransitionDiscreteGamma.h"
+#include "TransitionDiscreteWeibull.h"
+#include "TransitionDiscreteExponential.h"
+#include "TransitionLogNormal.h"
 
 class ModelJSON {
 private:
